==> org.apache.sling.models.impl-1.4.8-source-release.zip: org.apache.sling.models.impl-1.4.8/src/test/java/org/apache/sling/models/impl/injector/CustomAnnotationInjector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sling.models.impl.injector;

import java.lang.reflect.AnnotatedElement;
import java.lang.reflect.Type;

import javax.annotation.Nonnull;

import org.apache.sling.models.spi.DisposalCallbackRegistry;
import org.apache.sling.models.spi.Injector;
import org.apache.sling.models.spi.injectorspecific.AbstractInjectAnnotationProcessor;
import org.apache.sling.models.spi.injectorspecific.InjectAnnotationProcessor;
import org.apache.sling.models.spi.injectorspecific.InjectAnnotationProcessorFactory;

@SuppressWarnings("deprecation")
public class CustomAnnotationInjector implements Injector, InjectAnnotationProcessorFactory {

    @Override
    public @Nonnull String getName() {
        return "with-annotation";
    }

    @Override
    public Object getValue(@Nonnull Object adaptable, String name, @Nonnull Type declaredType, @Nonnull AnnotatedElement element,
            @Nonnull DisposalCallbackRegistry callbackRegistry) {
        if (name.equals("customString")) {
            return "custom value";
        } else {
            return null;
        }
    }

    @Override
    public InjectAnnotationProcessor createAnnotationProcessor(Object adaptable, AnnotatedElement element) {
        if (element.isAnnotationPresent(CustomAnnotation.class)) {
            return new Processor();
        } else {
            return null;
        }
    }

    private class Processor extends AbstractInjectAnnotationProcessor {

        @Override
        public boolean hasDefault() {
            return true;
        }

        @Override
        public Object getDefault() {
            return "default value";
        }
    }

}

==> org.apache.sling.models.impl-1.4.16-source-release.zip: org.apache.sling.models.impl-1.4.16/src/test/java/org/apache/sling/models/impl/injector/CustomAnnotationInjector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sling.models.impl.injector;

import java.lang.reflect.AnnotatedElement;
import java.lang.reflect.Type;

import org.apache.sling.models.spi.DisposalCallbackRegistry;
import org.apache.sling.models.spi.Injector;
import org.apache.sling.models.spi.injectorspecific.AbstractInjectAnnotationProcessor;
import org.apache.sling.models.spi.injectorspecific.InjectAnnotationProcessor;
import org.apache.sling.models.spi.injectorspecific.InjectAnnotationProcessorFactory;
import org.jetbrains.annotations.NotNull;

@SuppressWarnings("deprecation")
public class CustomAnnotationInjector implements Injector, InjectAnnotationProcessorFactory {

    @Override
    public @NotNull String getName() {
        return "with-annotation";
    }

    @Override
    public Object getValue(@NotNull Object adaptable, String name, @NotNull Type declaredType, @NotNull AnnotatedElement element,
            @NotNull DisposalCallbackRegistry callbackRegistry) {
        if (name.equals("customString")) {
            return "custom value";
        } else {
            return null;
        }
    }

    @Override
    public InjectAnnotationProcessor createAnnotationProcessor(Object adaptable, AnnotatedElement element) {
        if (element.isAnnotationPresent(CustomAnnotation.class)) {
            return new Processor();
        } else {
            return null;
        }
    }

    private class Processor extends AbstractInjectAnnotationProcessor {

        @Override
        public boolean hasDefault() {
            return true;
        }

        @Override
        public Object getDefault() {
            return "default value";
        }
    }

}
